from karabo.bound import KARABO_CLASSINFO
from TrainMatcher import TrainMatcher

from . import shmem_utils
from ._version import version as deviceVersion


@KARABO_CLASSINFO("ShmemTrainMatcher", deviceVersion)
class ShmemTrainMatcher(TrainMatcher.TrainMatcher):
    def initialization(self):
        super().initialization()
        self._shmem_handler = shmem_utils.ShmemCircularBufferReceiver()

    def on_matched_data(self, train_id, sources):
        for source, (data, timestamp) in sources.items():
            if data.has("calngShmemPaths"):
                shmem_paths = list(data["calngShmemPaths"])
                data.erase("calngShmemPaths")
                for shmem_path in shmem_paths:
                    if not data.has(shmem_path):
                        self.log.INFO(f"Hash from {source} did not have {shmem_path}")
                        continue
                    dereferenced = self._shmem_handler.get(data[shmem_path])
                    data[shmem_path] = dereferenced

        super().on_matched_data(train_id, sources)
